intelmq.bots.outputs.stomp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.stomp package

## Submodules

## intelmq.bots.outputs.stomp.output module

`intelmq.bots.outputs.stomp.output.` `BOT`

  alias of `intelmq.bots.outputs.stomp.output.StompOutputBot`

class `intelmq.bots.outputs.stomp.output.` `StompOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  main class for the STOMP protocol output bot

  `conn` = None
  `connect`()
  `init`()
  `process`()
  `shutdown`()

## Module contents